@@ -14,6 +14,7 @@
 #include "marks.h"
 #include "video.h"
 #include "tools.h"
+#include "logo.h"
 
 /**
  * evaluate stop/start pair status
@@ -28,49 +29,16 @@ enum eEvaluateStatus {
 
 
 
-/**
- * class to evaluate channel special logos types
- */
-class cEvaluateChannel : protected cTools {
-public:
-
-    /**
-     * check if channel could have info logos
-     * @return true if channel could have info logos, false otherwise
-     */
-    bool IsInfoLogoChannel(const char *channelName);
-
-    /**
-     * check if channel could have logo changes
-     * @return true if channel could have logo changes, false otherwise
-     */
-    bool IsLogoChangeChannel(const char *channelName);
-
-    /**
-     * check if channel could have closing credits without logo
-     * @return true if channel could have closing credits without logo, false otherwise
-     */
-    bool ClosingCreditsChannel(const char *channelName);
-
-    /**
-     * check if channel could have advertising in frame with logo
-     * @return true if channel advertising in frame with logo, false otherwise
-     */
-    bool AdInFrameWithLogoChannel(const char *channelName);
-
-    /**
-     * check for introduction logo
-     * @return true if introduction logo detected, false otherwise
-     */
-    bool IntroductionLogoChannel(const char *channelName);
-};
-
-
 /**
  * class to evaluate logo stop/start pair
  */
-class cEvaluateLogoStopStartPair : public cEvaluateChannel {
+class cEvaluateLogoStopStartPair {
 public:
+    /**
+     * class to evaluate stop / start pair for special logos (info logo, logo change nd introduction logo"
+     */
+    cEvaluateLogoStopStartPair(cDecoder *decoderParam, cCriteria *criteriaParam);
+    ~cEvaluateLogoStopStartPair();
 
     /**
      * logo stop / start pair
@@ -92,20 +60,15 @@ public:
         //!<
     };
 
-    cEvaluateLogoStopStartPair();
-    ~cEvaluateLogoStopStartPair();
-
     /**
      * check logo stop/start pairs
-     * @param maContext       markad context
      * @param marks           object with all marks
      * @param blackMarks      object with all black screen marks
      * @param iStart          assumed start frame position
      * @param chkSTART        frame position to check start part
      * @param iStopA          assumed end mark position
      */
-    void CheckLogoStopStartPairs(sMarkAdContext *maContext, cMarks *marks, cMarks *blackMarks, const int iStart, const int chkSTART, const int iStopA);
-
+    void CheckLogoStopStartPairs(cMarks *marks, cMarks *blackMarks, const int iStart, const int chkSTART, const int iStopA);
 
     /**
      * check if logo stop/start pair could be closing credits
@@ -118,21 +81,19 @@ public:
      * check if logo stop/start pair could be a logo change
      * @param[in]     marks             object with all marks
      * @param[in,out] logoStopStartPair structure of logo/stop start pair, result is stored here, isLogoChange is set to -1 if the part is no logo change
-     * @param[in]     framesPerSecond   video frame rate
      * @param[in]     iStart            assumed start mark position
      * @param[in]     chkSTART          search for start mark position
      */
-    static void IsLogoChange(cMarks *marks, sLogoStopStartPair *logoStopStartPair, const int framesPerSecond, const int iStart, const int chkSTART);
+    void IsLogoChange(cMarks *marks, sLogoStopStartPair *logoStopStartPair, const int iStart, const int chkSTART);
 
     /**
      * check if logo stop/start pair could be an info logo
      * @param marks             object with all marks
      * @param blackMarks        object with all black screen marks
      * @param logoStopStartPair structure of logo/stop start pair, result is stored here
-     * @param framesPerSecond   video frame rate
-     * @param iStart            assumed start frame number
+     * @param iStopA            assumed stop frame number
      */
-    static void IsInfoLogo(cMarks *marks, cMarks *blackMarks, sLogoStopStartPair *logoStopStartPair, const int framesPerSecond, const int iStart);
+    void IsInfoLogo(cMarks *marks, cMarks *blackMarks, sLogoStopStartPair *logoStopStartPair, const int iStopA);
 
     /**
      * get next logo stop/start pair
@@ -214,6 +175,10 @@ public:
     bool IncludesInfoLogo(const int stopPosition, const int startPosition);
 
 private:
+    cDecoder *decoder   = nullptr;                                  //!< pointer to decoder
+    //!<
+    cCriteria *criteria = nullptr;                                  //!< analyse criteria
+    //!<
     std::vector<sLogoStopStartPair> logoPairVector;                 //!< logo stop/start pair vector
     //!<
     std::vector<sLogoStopStartPair>::iterator nextLogoPairIterator; //!< iterator for logo stop/start pair vector
@@ -224,20 +189,50 @@ private:
 /**
  * class to calculate logo size
  */
-class cDetectLogoStopStart : public cLogoSize, public cEvaluateChannel {
+class cDetectLogoStopStart {
 public:
     /**
      * constructor for class to dectect special logo stop/start pair
-     * @param maContextParam                 markad context
+     * @param decoderParam                   pointer to decoder
+     * @param indexParam                     pointer to recording index
      * @param criteriaParam                  detection criteria
-     * @param ptr_cDecoderParam              decoder
-     * @param recordingIndexParam            recording index
+     * @param logoCornerParam                logo corner index
      * @param evaluateLogoStopStartPairParam class to evaluate logo stop/start pairs
      */
-    cDetectLogoStopStart(sMarkAdContext *maContextParam, cCriteria *criteriaParam, cDecoder *ptr_cDecoderParam, cIndex *recordingIndexParam, cEvaluateLogoStopStartPair *evaluateLogoStopStartPairParam);
+    cDetectLogoStopStart(cDecoder *decoderParam, cIndex *indexParam, cCriteria *criteriaParam, cEvaluateLogoStopStartPair *evaluateLogoStopStartPairParam, const int logoCornerParam);
 
     ~cDetectLogoStopStart();
 
+    /**
+    * copy constructor
+    */
+    cDetectLogoStopStart(const cDetectLogoStopStart &origin) {
+        memcpy(aCorner, origin.aCorner, sizeof(origin.aCorner));
+        evaluateLogoStopStartPair = origin.evaluateLogoStopStartPair;
+        compareResult = origin.compareResult;
+        sobel = nullptr;
+        logoCorner = origin.logoCorner;
+        criteria = origin.criteria;
+        index = origin.index;
+        decoder =origin.decoder;
+    }
+
+    /**
+     * operator=
+     */
+    cDetectLogoStopStart &operator =(const cDetectLogoStopStart *origin) {
+        memcpy(aCorner, origin->aCorner, sizeof(origin->aCorner));
+        evaluateLogoStopStartPair = origin->evaluateLogoStopStartPair;
+        compareResult = origin->compareResult;
+        sobel = origin->sobel;
+        logoCorner = origin->logoCorner;
+        criteria = origin->criteria;
+        index = origin->index;
+        decoder = origin->decoder;
+        return *this;
+    }
+
+
     /**
      * find first pixel in a sobel transformed picture
      * @param      picture sobel transformed picture
@@ -251,7 +246,6 @@ public:
      */
     int FindFrameFirstPixel(const uchar *picture, const int corner, const int width, const int height, int startX, int startY, const int offsetX, const int offsetY);
 
-
     /**
      * find start position of a possible frame in a sobel transformed picture
      * @param         picture sobel transformed picture
@@ -264,7 +258,6 @@ public:
      */
     int FindFrameStartPixel(const uchar *picture, const int width, const int height,  int startX, int startY, const int offsetX, const int offsetY);
 
-
     /**
      * find start position of a possible frame in a sobel transformed picture
      * @param         picture sobel transformed picture
@@ -281,13 +274,12 @@ public:
 
     /**
      * detect a frame in a sobel transformed picture
-     * @param frameNumber current frame number
      * @param picture     plane 0 of sobel transformed picture
      * @param width       picture width in pixel
      * @param height      picture height in pixel
      * @param corner      source corner of picture
      */
-    int DetectFrame(const int frameNumber, const uchar *picture, const int width, const int height, const int corner);
+    int DetectFrame(const uchar *picture, const int width, const int height, const int corner);
 
     /**
      * compare all frames in range and calculate similar rate
@@ -303,64 +295,79 @@ public:
      * fade in/out is possible
      * @return true if part is info logo, false otherwise
      */
-    bool IsInfoLogo();
+    bool IsInfoLogo(int startPos, int endPos);
 
 /// check for logo change
     /**
      * logo change parts contains dynamic changing alternative logos (used only by TELE5)
      * @return true if part contains a logo change, false otherwise
      */
-    bool IsLogoChange();
+    bool IsLogoChange(int startPos, int endPos);
 
     /**
      * check for closing credits without logo and for closing still image
      * @return frame number of end of closing credits or closing still image
      */
-    int ClosingCredit(const bool noLogoCorner = false);
+    int ClosingCredit(int startPos, int endPos, const bool noLogoCorner = false);
 
     /**
      * check if current range is an advertising in frame with logo
+     * @param startPos  start frame position
+     * @param endPos    end   frame position
      * @param isStartMark true if called to check after start mark, false if called to check before stop mark
+     * @param isEndMark   true if called to check after stop mark, false if called to check before stop mark
      * @return first frame of advertising in frame with logo before logo stop mark or last frame of advertising in frame with logo after logo start mark <br>
      *         -1 if no advertising in frame with logo was found
      */
-    int AdInFrameWithLogo(const bool isStartMark);
+    int AdInFrameWithLogo(int startPos, int endPos, const bool isStartMark, const bool isEndMark);
 
     /**
      * check if current range is a introduction logo
      * @return last frame of the introduction logo after logo start mark
      */
-    int IntroductionLogo();
+    int IntroductionLogo(int startPos, int endPos);
 
 private:
+    /**
+     * compair two logos
+     * @param logo1      first logo
+     * @param logo2      second logo
+     * @param logoHeight logo height
+     * @param logoWidth  logo width
+     * @param corner     logo corner
+     * @param rate0      similar rate
+     * @return true if compair was successful
+     */
+    bool CompareLogoPair(const sLogoInfo *logo1, const sLogoInfo *logo2, const int logoHeight, const int logoWidth, const int corner, int *rate0);
 
-    sMarkAdContext *maContext;                              //!< markad context
+    cDecoder *decoder         = nullptr;  //!< decoder
     //!<
-    cCriteria *criteria;                                    //!< class for mark detection criteria
+    cIndex *index             = nullptr;  //!< decoder
     //!<
-    cDecoder *ptr_cDecoder;                                 //!< decoder
+    cCriteria *criteria       = nullptr;  //!< class for mark detection criteria
     //!<
-    cIndex *recordingIndex;                                 //!< recording index
+    sAreaT area               = {};       //!< result area
     //!<
-    cEvaluateLogoStopStartPair *evaluateLogoStopStartPair;  //!< class to evaluate logo stop/start pairs
+    int logoCorner            = -1;       //!< index of logo corner
     //!<
-    int startPos = 0;                                       //!< frame number of start position to compare
-    //!<
-    int endPos   = 0;                                       //!< frame number of end position to compare
+    cSobel *sobel             = nullptr;  //!< class for sobel transformation
     //!<
     /**
      * compare two frames
      */
     struct sCompareInfo {
-        int frameNumber1 = 0;                //!< frame number 1
-        int frameNumber2 = 0;                //!< frame number 2
+        int frameNumber1          = 0;       //!< frame number 1
         //!<
-        int rate[CORNERS] = {0};             //!< similar rate of frame pair per corner
+        int frameNumber2          = 0;       //!< frame number 2
+        //!<
+        int rate[CORNERS]         = {0};     //!< similar rate of frame pair per corner
         //!<
         int framePortion[CORNERS] = {0};     //!< portion of frame pixels of corner
         //!<
     };
-    std::vector<sCompareInfo> compareResult; //!< vector of frame compare results
+    std::vector<sCompareInfo> compareResult;                //!< vector of frame compare results
+    //!<
+    cEvaluateLogoStopStartPair *evaluateLogoStopStartPair;  //!< class to evaluate logo stop/start pairs
     //!<
     const char *aCorner[CORNERS] = { "TOP_LEFT", "TOP_RIGHT", "BOTTOM_LEFT", "BOTTOM_RIGHT" };  //!< array to convert corner anum to text
     //!<
