@@ -24,23 +24,25 @@ cPluginMarkAd::cPluginMarkAd(void) {
     // Initialize any member variables here.
     // DON'T DO ANYTHING ELSE THAT MAY HAVE SIDE EFFECTS, REQUIRE GLOBAL
     // VDR OBJECTS TO EXIST OR PRODUCE ANY OUTPUT!
-    statusMonitor = NULL;
+    statusMonitor = nullptr;
+
     bindir = strdup(DEF_BINDIR);
     ALLOC(strlen(bindir)+1, "bindir");
+
     logodir = strdup(DEF_LOGODIR);
     ALLOC(strlen(logodir)+1, "logodir");
+
     title[0]                = 0;
     setup.ProcessDuring     = PROCESS_NEVER;
     setup.whileRecording    = true;
     setup.whileReplaying    = true;
     setup.OSDMessage        = false;
     setup.Verbose           = false;
-    setup.NoMargins         = false;
     setup.HideMainMenuEntry = false;
-    setup.SecondPass        = true;
     setup.Log2Rec           = false;
     setup.LogoOnly          = true;
     setup.DeferredShutdown  = true;
+    setup.hwaccel           = 0;
 }
 
 
@@ -98,19 +100,18 @@ const char *cPluginMarkAd::CommandLineHelp(void) {
 bool cPluginMarkAd::ProcessArgs(int argc, char *argv[]) {
     // Command line argument processing
     static struct option long_options[] = {
-        { "bindir",       required_argument, NULL, 'b'},
-        { "logocachedir", required_argument, NULL, 'l'},
-        { "loglevel",     required_argument, NULL, '1'},
-        { "astopoffs",    required_argument, NULL, '2'},
-        { "cDecoder",     no_argument,       NULL, '3'},
-        { "cut",          no_argument,       NULL, '4'},
-        { "ac3reencode",  no_argument,       NULL, '5'},
-        { "autologo",     required_argument, NULL, '6'},
-        { NULL, 0, NULL, 0 }
+        { "bindir",       required_argument, nullptr, 'b'},
+        { "logocachedir", required_argument, nullptr, 'l'},
+        { "loglevel",     required_argument, nullptr, '1'},
+        { "astopoffs",    required_argument, nullptr, '2'},
+        { "cut",          no_argument,       nullptr, '4'},
+        { "ac3reencode",  no_argument,       nullptr, '5'},
+        { "autologo",     required_argument, nullptr, '6'},
+        { nullptr, 0, nullptr, 0 }
     };
 
     int c;
-    while ((c = getopt_long(argc, argv, "b:l:", long_options, NULL)) != -1) {
+    while ((c = getopt_long(argc, argv, "b:l:", long_options, nullptr)) != -1) {
         switch (c) {
         case 'b':
             if ((access(optarg,R_OK | X_OK)) != -1) {
@@ -147,15 +148,12 @@ bool cPluginMarkAd::ProcessArgs(int argc, char *argv[]) {
             astopoffs = atoi(optarg);
             break;
         case '3':
-            fprintf(stderr,"markad: parameter --cDecoder: is depreciated, please remove it from your configuration\n");
-            break;
-        case '4':
             MarkadCut = true;
             break;
-        case '5':
+        case '4':
             ac3ReEncode = true;
             break;
-        case '6':
+        case '5':
             autoLogoConf = atoi(optarg);
             break;
         default:
@@ -187,7 +185,7 @@ bool cPluginMarkAd::Initialize(void) {
     dsyslog("markad: cPluginMarkAd::Initialize(): create status monitor");
     statusMonitor = new cStatusMarkAd(bindir, logodir, &setup);
     ALLOC(sizeof(*statusMonitor), "statusMonitor");
-    return (statusMonitor!=NULL);
+    return (statusMonitor!=nullptr);
 }
 
 
@@ -228,7 +226,7 @@ void cPluginMarkAd::Housekeeping(void) {
 void cPluginMarkAd::MainThreadHook(void) {
     // Perform actions in the context of the main program thread.
     // WARNING: Use with great care - see PLUGINS.html!
-    time_t now = time(NULL);
+    time_t now = time(nullptr);
     if (now > (lastcheck + 5)) {
         statusMonitor->Check();
         lastcheck = now;
@@ -244,7 +242,7 @@ cString cPluginMarkAd::Active(void) {
         return tr("markad still running");
     }
     dsyslog("markad: shutdown request accepted");
-    return NULL;
+    return nullptr;
 }
 
 
@@ -268,22 +266,21 @@ cMenuSetupPage *cPluginMarkAd::SetupMenu(void) {
 
 bool cPluginMarkAd::SetupParse(const char *Name, const char *Value) {
     // Parse setup parameters and store their values.
-    if (!strcasecmp(Name,"Execution")) setup.ProcessDuring = atoi(Value);
-    else if (!strcasecmp(Name,"useVPS")) setup.useVPS = atoi(Value);
-    else if (!strcasecmp(Name,"logVPS")) setup.logVPS = atoi(Value);
-    else if (!strcasecmp(Name,"whileRecording")) setup.whileRecording = atoi(Value);
-    else if (!strcasecmp(Name,"whileReplaying")) setup.whileReplaying = atoi(Value);
-    else if (!strcasecmp(Name,"OSDMessage")) setup.OSDMessage = atoi(Value);
-    else if (!strcasecmp(Name,"svdrPort")) setup.svdrPort = atoi(Value);
-    else if (!strcasecmp(Name,"Verbose")) setup.Verbose = atoi(Value);
-    else if (!strcasecmp(Name,"IgnoreMargins")) setup.NoMargins = atoi(Value);
-    else if (!strcasecmp(Name,"HideMainMenuEntry")) setup.HideMainMenuEntry = atoi(Value)?true:false;
-    else if (!strcasecmp(Name,"SecondPass")) setup.SecondPass = atoi(Value);
-    else if (!strcasecmp(Name,"Log2Rec")) setup.Log2Rec = atoi(Value);
-    else if (!strcasecmp(Name,"LogoOnly")) setup.LogoOnly = atoi(Value);
-    else if (!strcasecmp(Name,"DeferredShutdown")) setup.DeferredShutdown = atoi(Value);
-    else if (!strcasecmp(Name,"AutoLogoExtraction")) setup.autoLogoMenu = atoi(Value);
-    else if (!strcasecmp(Name,"FullDecode")) setup.fulldecode = atoi(Value);
+    if (!strcasecmp(Name,"Execution"))               setup.ProcessDuring     = atoi(Value);
+    else if (!strcasecmp(Name,"useVPS"))             setup.useVPS            = atoi(Value);
+    else if (!strcasecmp(Name,"logVPS"))             setup.logVPS            = atoi(Value);
+    else if (!strcasecmp(Name,"whileRecording"))     setup.whileRecording    = atoi(Value);
+    else if (!strcasecmp(Name,"whileReplaying"))     setup.whileReplaying    = atoi(Value);
+    else if (!strcasecmp(Name,"OSDMessage"))         setup.OSDMessage        = atoi(Value);
+    else if (!strcasecmp(Name,"svdrPort"))           setup.svdrPort          = atoi(Value);
+    else if (!strcasecmp(Name,"Verbose"))            setup.Verbose           = atoi(Value);
+    else if (!strcasecmp(Name,"HideMainMenuEntry"))  setup.HideMainMenuEntry = atoi(Value)?true:false;
+    else if (!strcasecmp(Name,"Log2Rec"))            setup.Log2Rec           = atoi(Value);
+    else if (!strcasecmp(Name,"LogoOnly"))           setup.LogoOnly          = atoi(Value);
+    else if (!strcasecmp(Name,"DeferredShutdown"))   setup.DeferredShutdown  = atoi(Value);
+    else if (!strcasecmp(Name,"AutoLogoExtraction")) setup.autoLogoMenu      = atoi(Value);
+    else if (!strcasecmp(Name,"FullDecode"))         setup.fulldecode        = atoi(Value);
+    else if (!strcasecmp(Name,"hwaccel"))            setup.hwaccel           = atoi(Value);
     else return false;
     return true;
 }
@@ -291,7 +288,7 @@ bool cPluginMarkAd::SetupParse(const char *Name, const char *Value) {
 
 const char *cPluginMarkAd::MainMenuEntry(void) {
     if (setup.HideMainMenuEntry)
-        return NULL;
+        return nullptr;
     else
         return tr("markad status");
 }
@@ -314,7 +311,7 @@ const char **cPluginMarkAd::SVDRPHelpPages(void) {
         "DEBUG_MEM\n"
         "     show current allocated heap memory",
 #endif
-        NULL
+        nullptr
     };
     return HelpPage;
 }
@@ -331,7 +328,7 @@ bool cPluginMarkAd::ReadTitle(const char *Directory) {
     f = fopen(buf,"r");
     FREE(strlen(buf)+1, "buf");
     free(buf);
-    buf = NULL;
+    buf = nullptr;
     if (!f) {
         if (asprintf(&buf, "%s/info.vdr",Directory) == -1) return false;
         ALLOC(strlen(buf)+1, "buf");
@@ -341,7 +338,7 @@ bool cPluginMarkAd::ReadTitle(const char *Directory) {
         if (!f) return false;
     }
 
-    char *line = NULL;
+    char *line = nullptr;
     size_t length;
     while (getline(&line, &length, f) != -1) {
         if (line[0] == 'T') {
@@ -372,7 +369,7 @@ cString cPluginMarkAd::SVDRPCommand(const char *Command, const char *Option, int
     // start markad via SVDRP command, timerVPS will be detected by markad, we don't know this here
     if (strcasecmp(Command, "MARK") == 0) {
         if (Option) {
-            const char *Title = NULL;
+            const char *Title = nullptr;
             if (ReadTitle(Option)) Title = reinterpret_cast<char *>(&title);
             sRecording recording;
             if (statusMonitor->Start(Title, Option, true, &recording)) {
@@ -396,6 +393,6 @@ cString cPluginMarkAd::SVDRPCommand(const char *Command, const char *Option, int
         return memListSVDR();
     }
 #endif
-    return NULL;
+    return nullptr;
 }
 VDRPLUGINCREATOR(cPluginMarkAd) // Don't touch this!
